@@ -14,17 +14,21 @@ class CConfigManager {
     CConfigManager(CConfigManager&&)      = delete;
 
     struct SSetting {
-        std::string monitor, fitMode, path;
-        uint32_t    id = 0;
+        std::string              monitor, fitMode;
+        std::vector<std::string> paths;
+        int                      timeout = 0;
+        uint32_t                 id      = 0;
     };
 
     constexpr static const uint32_t SETTING_INVALID = 0;
 
-    void                            init();
+    bool                            init();
     Hyprlang::CConfig*              hyprlang();
 
     std::vector<SSetting>           getSettings();
 
+    const std::string&              getCurrentConfigPath() const;
+
   private:
     Hyprlang::CConfig m_config;
 
